@@ -2,7 +2,7 @@ test_that("read_iris returns valid data set",{
   filename = btcore_file("IrisMulti.TXT")
   f = read_iris(filename)
 
-  expect_is(f,"breathtest_data")
+  expect_s3_class(f,"breathtest_data")
   expect_equal(f$file_name, basename(filename))
   expect_equal(f$name,"V")
   expect_equal(f$first_name,"S")
@@ -26,7 +26,7 @@ test_that("read_iris from text and from file give almost the same results",{
 test_that("read_iris returns valid data set when values are negative",{
   filename = btcore_file("IrisNegativeValues.TXT")
   f = read_iris(filename)
-  expect_is(f,"breathtest_data")
+  expect_s3_class(f,"breathtest_data")
   expect_equal(nrow(f$data),12)
   expect_equal(ncol(f$data),3)
   expect_true(all(f$data$dob >= -10))
@@ -35,7 +35,7 @@ test_that("read_iris returns valid data set when values are negative",{
 test_that("read_iris returns valid data set when weight/height is zero",{
   filename = btcore_file("IrisZeroWeight.TXT")
   f = read_iris(filename)
-  expect_is(f,"breathtest_data")
+  expect_s3_class(f,"breathtest_data")
   expect_equal(f$weight, 75)
   expect_equal(f$height, 180)
   expect_equal(nrow(f$data),14)
@@ -45,7 +45,7 @@ test_that("read_iris returns valid data set when weight/height is zero",{
 test_that("read_iris correctly ready names with umlaut",{
   filename = btcore_file("Iris_Umlaut.TXT")
   f = read_iris(filename)
-  expect_is(f,"breathtest_data")
+  expect_s3_class(f,"breathtest_data")
   expect_equal(f$name, "Rüdigör")
   expect_equal(f$first_name, "Özgur")
   expect_equal(f$initials, "RÖ")
